package org.acme.microprofile.health;

import io.quarkus.test.junit.QuarkusIntegrationTest;

@QuarkusIntegrationTest
public class HealthCheckIT extends HealthCheckTest {
}
